@@ -14,16 +14,8 @@ Path = tp.Union[str, bytes, os.PathLike]
 __all__ = ["assemble", "assemble_file", "cli"]
 
 
-def assemble(assembly_code: str) -> bytes:  # type: ignore
-    import warnings
-
-    warnings.warn(
-        "The ISA specification may not be correct; This runs on the emulator, but may not run on the chip"  # noqa
-    )
-    try:
-        return encode_instructions(*parse(scan(assembly_code)))  # type: ignore
-    except AsmException as exc:
-        exc.error_exit()
+def assemble(assembly_code: str) -> bytes:
+    return encode_instructions(*parse(scan(assembly_code)))
 
 
 def assemble_file(source: Path, destination: Path) -> None:
@@ -45,7 +37,10 @@ def cli() -> None:
         help="The path of the destination file",
     )
     args = parser.parse_args()
-    assemble_file(args.source, args.destination)
+    try:
+        assemble_file(args.source, args.destination)
+    except AsmException as exc:
+        exc.error_exit()
 
 
 if __name__ == "__main__":
