@@ -19,6 +19,7 @@ def __getattr__(name: str) -> typing.Any:
 class TokenType(enum.Enum):
     INSTRUCTION = enum.auto()
     REGISTER = enum.auto()
+    MODED_REGISTER = enum.auto()
     SYNTAX = enum.auto()
     LABEL = enum.auto()
     STRING = enum.auto()
@@ -26,4 +27,4 @@ class TokenType(enum.Enum):
 
 
 # This is defined like this because of the special characters as the enum names
-Syntax = enum.Enum("Syntax", [",", "[", "]", "+", ":", "<<", ">>"])
+Syntax = enum.Enum("Syntax", [",", "[", "]", "+", ":", "<<", ">>", "ror", "ser"])
